@@ -4,14 +4,14 @@ import subprocess
 from typing import List, Dict, Optional
 
 from getdeck.configuration import ClientConfiguration
-from getdeck.provider.types import K8sProviderType
+from getdeck.provider.types import ProviderType
 from getdeck.provider.utility_provider import UtilityProvider
 
 logger = logging.getLogger("deck")
 
 
 class K3d(UtilityProvider):
-    kubernetes_cluster_type = K8sProviderType.k3d
+    kubernetes_cluster_type = ProviderType.K3D
     provider_type = "k3d"
     base_command = "k3d"
     _cluster = []
@@ -21,9 +21,8 @@ class K3d(UtilityProvider):
         config: ClientConfiguration,
         name: str,
         native_config: dict,
-        _debug_output=False,
+        _debug_output: bool = False,
     ):
-
         self.initialize(
             config,
             name,
@@ -57,29 +56,28 @@ class K3d(UtilityProvider):
         return self._cluster
 
     def get_kubeconfig(self) -> Optional[str]:
-        arguments = ["kubeconfig", "get", self.k3d_cluster_name]
+        arguments = ["kubeconfig", "get", self.cluster_name]
         return self._get_kubeconfig(arguments)
 
     def create(self):
-        arguments = ["cluster", "create", self.k3d_cluster_name]
+        arguments = ["cluster", "create", self.cluster_name]
         return self._create(arguments)
 
     def start(self):
-        arguments = ["cluster", "start", self.k3d_cluster_name]
+        arguments = ["cluster", "start", self.cluster_name]
         p = self._execute(arguments)
         if p.returncode != 0:
             return False
-        # data.kubeconfig_path = self.get_kubeconfig()
         return True
 
     def stop(self):
-        arguments = ["cluster", "stop", self.k3d_cluster_name]
+        arguments = ["cluster", "stop", self.cluster_name]
         self._execute(arguments)
         return True
 
     def delete(self):
-        logger.info(f"Deleting the k3d cluster with name {self.k3d_cluster_name}")
-        arguments = ["cluster", "delete", self.k3d_cluster_name]
+        logger.info(f"Deleting the k3d cluster with name {self.cluster_name}")
+        arguments = ["cluster", "delete", self.cluster_name]
         self._execute(arguments)
         return True
 
@@ -115,7 +113,5 @@ class K3dBuilder:
         native_config: dict = None,
         **_ignored,
     ):
-        # create instance
         instance = K3d(config=config, name=name, native_config=native_config)
-
         return instance
